==> haskell-bytestring-to-vector-0.3.0.1-47-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-to-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-to-vector
version:              0.3.0.1
visibility:           public
id:                   bytestring-to-vector-0.3.0.1-KCX9ikyM4BMFLTL2tTwKr2
key:                  bytestring-to-vector-0.3.0.1-KCX9ikyM4BMFLTL2tTwKr2
license:              BSD-3-Clause
maintainer:           Sven Heyll <sven.heyll@gmail.com>
author:               Keegan McAllister <mcallister.keegan@gmail.com>
homepage:             https://github.com/sheyll/bytestring-to-vector
synopsis:
    Convert between ByteString and Vector.Storable without copying

description:
    This library allows conversion between the types from @Data.ByteString@
    (package @bytestring@) and @Data.Vector.Storable@ (package @vector@) without
    copying the underlying data.  This is useful, for example, when @ByteString@
    IO produces or consumes vectors of numbers in native byte order.

    The conversion relies on the fact that @ByteString@ and @Vector@ use their
    respective @ForeignPtr@s in compatible ways.

    This library is a fork of the @spool@ package written by Keegan McAllister.

category:             Data Structures
abi:                  0ec786d2b005d0d833ecd4f0d762697f
exposed:              True
exposed-modules:      Data.Vector.Storable.ByteString
import-dirs:          /usr/lib/ghc-9.2.8/site-local/bytestring-to-vector-0.3.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bytestring-to-vector-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-to-vector
hs-libraries:         HSbytestring-to-vector-0.3.0.1-KCX9ikyM4BMFLTL2tTwKr2
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    vector-0.13.1.0-1Hbj4hORR7KGMeSpv0BhQN

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-to-vector/html/bytestring-to-vector.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-to-vector/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bytestring-to-vector-0.3.0.1-49-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-bytestring-to-vector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 bytestring-to-vector
version:              0.3.0.1
visibility:           public
id:                   bytestring-to-vector-0.3.0.1-9NKozRiNG8GADHYl2Ys5GP
key:                  bytestring-to-vector-0.3.0.1-9NKozRiNG8GADHYl2Ys5GP
license:              BSD-3-Clause
maintainer:           Sven Heyll <sven.heyll@gmail.com>
author:               Keegan McAllister <mcallister.keegan@gmail.com>
homepage:             https://github.com/sheyll/bytestring-to-vector
synopsis:
    Convert between ByteString and Vector.Storable without copying

description:
    This library allows conversion between the types from @Data.ByteString@
    (package @bytestring@) and @Data.Vector.Storable@ (package @vector@) without
    copying the underlying data.  This is useful, for example, when @ByteString@
    IO produces or consumes vectors of numbers in native byte order.

    The conversion relies on the fact that @ByteString@ and @Vector@ use their
    respective @ForeignPtr@s in compatible ways.

    This library is a fork of the @spool@ package written by Keegan McAllister.

category:             Data Structures
abi:                  51cd385c4323ccd721f78360b43e68bb
exposed:              True
exposed-modules:      Data.Vector.Storable.ByteString
import-dirs:          /usr/lib/ghc-9.2.8/site-local/bytestring-to-vector-0.3.0.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/bytestring-to-vector-0.3.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-bytestring-to-vector
hs-libraries:         HSbytestring-to-vector-0.3.0.1-9NKozRiNG8GADHYl2Ys5GP
depends:
    base-4.16.4.0 bytestring-0.11.4.0
    vector-0.13.1.0-6G7HaD4XqvmDrN5OhcYDtS

haddock-interfaces:
    /usr/share/doc/haskell-bytestring-to-vector/html/bytestring-to-vector.haddock

haddock-html:         /usr/share/doc/haskell-bytestring-to-vector/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
